==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicMenuItemUI__24MenuKeyHandler.h <==
// public class javax.swing.plaf.basic.BasicMenuItemUI$MenuKeyHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 645a20ff8313e3c0 javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler_H_
#define _JC_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_MenuKeyEvent$object;
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$refs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vmethods	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtable	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtype	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$method$_init$3de4006e6037e987(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$method$menuKeyPressed$6662c20bb2038c4e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object *, struct _jc_javax_swing_event_MenuKeyEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$method$menuKeyReleased$3252cf37b0ee7ce8(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object *, struct _jc_javax_swing_event_MenuKeyEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$method$menuKeyTyped$870ed9f626a4147e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object *, struct _jc_javax_swing_event_MenuKeyEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$method_info$menuKeyPressed$6662c20bb2038c4e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$method_info$menuKeyReleased$3252cf37b0ee7ce8;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$method_info$menuKeyTyped$870ed9f626a4147e;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vmethods {
	void	(*menuKeyPressed$6662c20bb2038c4e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object *, struct _jc_javax_swing_event_MenuKeyEvent$object *);
	void	(*menuKeyReleased$3252cf37b0ee7ce8)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object *, struct _jc_javax_swing_event_MenuKeyEvent$object *);
	void	(*menuKeyTyped$870ed9f626a4147e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object *, struct _jc_javax_swing_event_MenuKeyEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vmethods	javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicMenuItemUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$refs {
    _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_refs	javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_nonrefs	javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object {
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtype _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicMenuItemUI__24MenuKeyHandler.h <==
// public class javax.swing.plaf.basic.BasicMenuItemUI$MenuKeyHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e6cf37fa9fce1a62 javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler_H_
#define _JC_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_MenuKeyEvent$object;
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$refs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vmethods	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtable	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtype	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$method$_init$3de4006e6037e987(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$method$menuKeyPressed$6662c20bb2038c4e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object *, struct _jc_javax_swing_event_MenuKeyEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$method$menuKeyReleased$3252cf37b0ee7ce8(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object *, struct _jc_javax_swing_event_MenuKeyEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$method$menuKeyTyped$870ed9f626a4147e(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object *, struct _jc_javax_swing_event_MenuKeyEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$method_info$menuKeyPressed$6662c20bb2038c4e;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$method_info$menuKeyReleased$3252cf37b0ee7ce8;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$method_info$menuKeyTyped$870ed9f626a4147e;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vmethods {
	void	(*menuKeyPressed$6662c20bb2038c4e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object *, struct _jc_javax_swing_event_MenuKeyEvent$object *) _JC_JCNI_ATTR;
	void	(*menuKeyReleased$3252cf37b0ee7ce8)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object *, struct _jc_javax_swing_event_MenuKeyEvent$object *) _JC_JCNI_ATTR;
	void	(*menuKeyTyped$870ed9f626a4147e)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object *, struct _jc_javax_swing_event_MenuKeyEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vmethods	javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicMenuItemUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$refs {
    _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_refs	javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$sub_nonrefs	javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$object {
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$vtype _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicMenuItemUI__24MenuKeyHandler_H_ */
